aboutsummaryrefslogtreecommitdiff
path: root/Core.hs
diff options
context:
space:
mode:
authorGravatar Joey Hess <joey@kitenet.net>2010-10-25 20:19:08 -0400
committerGravatar Joey Hess <joey@kitenet.net>2010-10-25 20:19:08 -0400
commitfec9f611df1a5e973f4847ac71fe85bd85abdff4 (patch)
tree6e07ded9b85a030c3e6166688b2f968d6985167f /Core.hs
parenta0e8ba37c69a7ce69a6bca42b4e4a20d046b3566 (diff)
add setkey subcommand
And finished implementing move --to
Diffstat (limited to 'Core.hs')
-rw-r--r--Core.hs4
1 files changed, 3 insertions, 1 deletions
diff --git a/Core.hs b/Core.hs
index 0d95e382b..881b668e0 100644
--- a/Core.hs
+++ b/Core.hs
@@ -32,12 +32,14 @@ shutdown = do
liftIO $ Git.run g ["add", gitStateDir g]
- -- clean up any files left in the temp directory
+ -- clean up any files left in the temp directory, but leave
+ -- the tmp directory itself
let tmp = annexTmpLocation g
exists <- liftIO $ doesDirectoryExist tmp
if (exists)
then liftIO $ removeDirectoryRecursive $ tmp
else return ()
+ liftIO $ createDirectoryIfMissing True tmp
return True